==> univention-s4-connector_14.0.10-6A~5.0.0.202208301457.tar.gz: univention-s4-connector-14.0.10/modules/univention/admin/syntax.d/s4_connector.py <==
# -*- coding: utf-8 -*-
#
# Univention S4 Connector
#  UDM syntax classes
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2019-2022 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

from univention.admin.syntax import integer, _
import univention.admin.uexceptions


class SignedInteger(integer):  # Workaround for Bug #50591

	@classmethod
	def parse(cls, text):
		try:
			return str(int(text))
		except ValueError:
			raise univention.admin.uexceptions.valueError(_("Value must be a number!"))

==> univention-s4-connector_14.0.13-5A~5.0.0.202304191550.tar.gz: univention-s4-connector-14.0.13/modules/univention/admin/syntax.d/s4_connector.py <==
# -*- coding: utf-8 -*-
#
# Univention S4 Connector
#  UDM syntax classes
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2019-2023 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

import univention.admin.uexceptions
from univention.admin.syntax import _, integer


class SignedInteger(integer):  # Workaround for Bug #50591

    @classmethod
    def parse(cls, text):
        try:
            return str(int(text))
        except ValueError:
            raise univention.admin.uexceptions.valueError(_("Value must be a number!"))
